@@ -5,7 +5,7 @@
  *	This file is part of libHX. libHX is free software; you can
  *	redistribute it and/or modify it under the terms of the GNU
  *	Lesser General Public License as published by the Free Software
- *	Foundation; either version 2 or 3 of the License.
+ *	Foundation; either version 2.1 or 3 of the License.
  */
 #include <errno.h>
 #include <stdarg.h>
@@ -13,8 +13,9 @@
 #include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
-#include <libHX.h>
 #include <libHX/arbtree.h>
+#include <libHX/string.h>
+#include "internal.h"
 
 enum {
 	S_LEFT        = 0,
