@@ -5,14 +5,14 @@
  *	This file is part of libHX. libHX is free software; you can
  *	redistribute it and/or modify it under the terms of the GNU
  *	Lesser General Public License as published by the Free Software
- *	Foundation; either version 2 or 3 of the License.
+ *	Foundation; either version 2.1 or 3 of the License.
  */
 #include <errno.h>
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
-#include <libHX.h>
 #include <libHX/deque.h>
+#include "internal.h"
 
 static inline void HXdeque_add(struct HXdeque_node *, struct HXdeque_node *);
 static inline void HXdeque_drop(struct HXdeque *, struct HXdeque_node *);
