@@ -5,7 +5,7 @@
  *	This file is part of libHX. libHX is free software; you can
  *	redistribute it and/or modify it under the terms of the GNU
  *	Lesser General Public License as published by the Free Software
- *	Foundation; either version 2 or 3 of the License.
+ *	Foundation; either version 2.1 or 3 of the License.
  */
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -20,14 +20,14 @@
 #if defined _WIN32
 #	include <direct.h>
 #	include <io.h>
+#	include <windows.h>
+#else
+#	include <dirent.h>
+#	include <unistd.h>
 #endif
-#include "libHX.h"
-#ifndef S_IRUGO
-#	define S_IRUGO (S_IRUSR | S_IRGRP | S_IROTH)
-#endif
-#ifndef S_IWUGO
-#	define S_IWUGO (S_IWUSR | S_IWGRP | S_IWOTH)
-#endif
+#include <libHX/misc.h>
+#include <libHX/string.h>
+#include "internal.h"
 
 struct HXdir {
 #if defined _WIN32
@@ -260,7 +260,7 @@ EXPORT_SYMBOL int HX_rrmdir(const char *dir)
 {
 	struct HXdir *ptr;
 	const char *trav;
-	hmc_t *fn = NULL;
+	hxmc_t *fn = NULL;
 	int ret = 0;
 
 	if ((ptr = HXdir_open(dir)) == NULL)
@@ -271,10 +271,10 @@ EXPORT_SYMBOL int HX_rrmdir(const char *dir)
 
 		if (strcmp(trav, ".") == 0 || strcmp(trav, "..") == 0)
 			continue;
-		hmc_strasg(&fn, dir);
-		hmc_strcat(&fn, "/");
-		hmc_strcat(&fn, trav);
-		if (stat(fn, &sb) < 0) {
+		HXmc_strcpy(&fn, dir);
+		HXmc_strcat(&fn, "/");
+		HXmc_strcat(&fn, trav);
+		if (lstat(fn, &sb) < 0) {
 			ret = -errno;
 			break;
 		}
@@ -293,7 +293,7 @@ EXPORT_SYMBOL int HX_rrmdir(const char *dir)
 	if (rmdir(dir) < 0)
 		ret = -errno;
 	HXdir_close(ptr);
-	hmc_free(fn);
+	HXmc_free(fn);
 	return ret;
 }
 
@@ -301,7 +301,7 @@ EXPORT_SYMBOL int HX_rrmdir(const char *dir)
 static int mkdir_gen(const char *d)
 {
 	struct stat sb;
-	if (stat(d, &sb) < 0) {
+	if (lstat(d, &sb) < 0) {
 #if defined(_WIN32)
 		if (mkdir(d) < 0)
 #else
