@@ -1,16 +1,25 @@
 /*
  *	libHX/internal.h
- *	Copyright © Jan Engelhardt <jengelh [at] gmx de>, 1999 - 2007
+ *	Copyright © Jan Engelhardt <jengelh [at] gmx de>, 1999 - 2008
  *
  *	This file is part of libHX. libHX is free software; you can
  *	redistribute it and/or modify it under the terms of the GNU
  *	Lesser General Public License as published by the Free Software
- *	Foundation; either version 2 or 3 of the License.
+ *	Foundation; either version 2.1 or 3 of the License.
  */
 #ifndef LIBHX_INTERNAL_H
 #define LIBHX_INTERNAL_H 1
 
 #include "libHX/config.h"
+#include "libHX/defs.h"
+
+#ifdef __cplusplus
+	/* Only for our dual C/C++ testsuites */
+#	define const_cast(type, expr)       const_cast<type>(expr)
+#	define dynamic_cast(type, expr)     dynamic_cast<type>(expr)
+#	define static_cast(type, expr)      static_cast<type>(expr)
+#	define reinterpret_cast(type, expr) reinterpret_cast<type>(expr)
+#endif
 
 #ifdef __MINGW32__
 #	include "libHX/uxcompat.h"
@@ -26,25 +35,7 @@
 #	define EXPORT_SYMBOL
 #endif
 
-#ifndef O_BINARY
-#	define O_BINARY 0
-#endif
 #define MAXFNLEN 256  /* max length for filename buffer */
 #define MAXLNLEN 1024 /* max length for usual line */
 
-#define const_cast(type, expr)       ((type)(expr))
-#define static_cast(type, expr)      ((type)(expr))
-#define reinterpret_cast(type, expr) ((type)(expr))
-
-#ifndef offsetof
-#	define offsetof(type, member) \
-		reinterpret_cast(long, &(static_cast(type *, NULL)->member))
-#endif
-#ifndef containerof
-#	define containerof(var, type, member) reinterpret_cast(type *, \
-		reinterpret_cast(const char *, var) - offsetof(type, member))
-#endif
-
-#define BUILD_BUG_ON(condition) ((void)sizeof(char[1 - 2 * !!(condition)]))
-
 #endif /* LIBHX_INTERNAL_H */
