@@ -5,7 +5,7 @@
  *	This file is part of libHX. libHX is free software; you can
  *	redistribute it and/or modify it under the terms of the GNU
  *	Lesser General Public License as published by the Free Software
- *	Foundation; either version 2 or 3 of the License.
+ *	Foundation; either version 2.1 or 3 of the License.
  */
 
 /*
@@ -42,10 +42,15 @@
 #include <ctype.h>
 #include <errno.h>
 #include <stdbool.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "libHX.h"
+#include <libHX/deque.h>
+#include <libHX/misc.h>
+#include <libHX/option.h>
+#include <libHX/string.h>
+#include "internal.h"
 
 /* Definitions */
 #define CALL_CB \
@@ -175,6 +180,7 @@ EXPORT_SYMBOL int HX_getopt(const struct HXoption *table, int *argc,
 
 			do_assign(&cbi);
 			free(key);
+			key   = NULL;
 			state = S_NORMAL;
 			/* fallthrough */
 		}
@@ -208,6 +214,7 @@ EXPORT_SYMBOL int HX_getopt(const struct HXoption *table, int *argc,
 			do_assign(&cbi);
 
 			free(key);
+			key   = NULL;
 			state = S_NORMAL;
 			cur   = *++opt;
 			/* fallthrough */
@@ -395,7 +402,7 @@ EXPORT_SYMBOL int HX_getopt(const struct HXoption *table, int *argc,
 		 */
 		HX_zvecfree((char **)*argv);
 
-	*argv = static_cast(const char **, HXdeque_to_vec(remaining, &argk));
+	*argv = const_cast(const char **, HXdeque_to_vec(remaining, &argk));
 	*argc = argk;
 	HXdeque_free(remaining);
 	return 1;
@@ -537,7 +544,7 @@ EXPORT_SYMBOL int HX_shconfig(const char *file, const struct HXoption *table)
 {
 	struct HXoptcb cbi = {.table = table, .match_sh = '\0'};
 	char *reparse = NULL;
-	hmc_t *ln = NULL;
+	hxmc_t *ln = NULL;
 	FILE *fp;
 
 	if ((fp = fopen(file, "r")) == NULL)
@@ -580,7 +587,7 @@ EXPORT_SYMBOL int HX_shconfig(const char *file, const struct HXoption *table)
 		}
 	}
 
-	hmc_free(ln);
+	HXmc_free(ln);
 	fclose(fp);
 	return 1;
 }
@@ -667,9 +674,17 @@ static void do_assign(struct HXoptcb *cbi)
 	NTYPE_S(HXTYPE_INT,    int);
 	NTYPE_U(HXTYPE_ULONG,  unsigned long);
 	NTYPE_S(HXTYPE_LONG,   long);
+	NTYPE_U(HXTYPE_UINT8,  uint8_t);
+	NTYPE_S(HXTYPE_INT8,   int8_t);
+	NTYPE_U(HXTYPE_UINT16, uint16_t);
+	NTYPE_S(HXTYPE_INT16,  int16_t);
+	NTYPE_U(HXTYPE_UINT32, uint32_t);
+	NTYPE_S(HXTYPE_INT32,  int32_t);
 #ifndef _MSC_VER
 	NTYPE(HXTYPE_ULLONG,   unsigned long long, strtoull);
 	NTYPE(HXTYPE_LLONG,    long long, strtoll);
+	NTYPE(HXTYPE_UINT64,   uint64_t, strtoull);
+	NTYPE(HXTYPE_INT64,    int64_t, strtoll);
 #endif
 	case HXTYPE_FLOAT:
 		cbi->data_dbl = strtod(cbi->data, NULL);
