@@ -5,7 +5,7 @@
  *	This file is part of libHX. libHX is free software; you can
  *	redistribute it and/or modify it under the terms of the GNU
  *	Lesser General Public License as published by the Free Software
- *	Foundation; either version 2 or 3 of the License.
+ *	Foundation; either version 2.1 or 3 of the License.
  */
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -16,7 +16,8 @@
 #ifdef __unix__
 #	include <unistd.h>
 #endif
-#include "libHX.h"
+#include <libHX/misc.h>
+#include "internal.h"
 
 static int rand_fd = -1;
 
